<h1 align="center">
print.py
</h1>
<p align="center">
<sup>
A sophisticated wrapper around print
</sup>
</p>

----

## Why use print.py?
print.py is elegant and simple to use, not to mention it's elegant and beautiful code.  

## Features
- print
    - args
    - kwargs

## How to install??
You must have node.js and npm to install print.py.
```cpp
$ node
>>> const { exec } = require('child_process');
>>> exec('pip install print.py');
```
## Examples
```js 
from print import print

print('Hello')  # Prints out "Hello" 😱 
```